package client;

import java.io.*;

public class NetworkUtilities {
	/* Some global CONSTANTS */
	public static final int SERVERPORT = 5678;

	public static final byte REGISTER = 0x01;

	public static final byte GETUSERS = 0x02;
	public static final byte USERLIST = 0x03;

	public static final byte MESSAGE = 0x06;

	/* Some helpful methods */

	/**
	 * Writes the lower 2 bytes of the given integer to the stream
	 * (most significant byte first).
	 */
	public static void write16(OutputStream out, int value) throws IOException {
		out.write((value & 0xff00) >> 8);
		out.write(value & 0xff);
	}

	/**
	 * Reads a 2-byte (unsigned) number from the stream
	 * (most significant byte first) and returns it as integer.
	 */
	public static int read16(InputStream in) throws IOException {
		return ((in.read() << 8) | in.read());
	}

	/**
	 * Puts the lower 2 bytes of the given integer into the
	 * array (most significant byte first) starting at the
	 * given index. Similar to write16().
	 */
	public static void put16(int value, byte[] buffer, int index) {
		buffer[index] = (byte)((value & 0xff00) >> 8);
		buffer[index+1] = (byte)(value & 0xff);
	}

	/**
	 * Reads a 2-byte (unsigned) number from the array
	 * (most significant byte first) starting at the
	 * given index and returns it as integer. Similar to
	 * read16().
	 */
	public static int get16(byte[] buffer, int index) {
		return ((buffer[index] << 8) | (buffer[index+1] & 0xff));
	}
}